==> zio-aws-ec2_2.13-5.17.125.1-sources.jar: zio/aws/ec2/model/DescribeLocalGatewayRouteTableVpcAssociationsRequest.scala <==
package zio.aws.ec2.model
import java.lang.Integer
import zio.aws.ec2.model.primitives.{
  LocalGatewayMaxResults,
  LocalGatewayRouteTableVpcAssociationId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeLocalGatewayRouteTableVpcAssociationsRequest(
    localGatewayRouteTableVpcAssociationIds: Option[
      Iterable[LocalGatewayRouteTableVpcAssociationId]
    ] = None,
    filters: Option[Iterable[zio.aws.ec2.model.Filter]] = None,
    maxResults: Option[LocalGatewayMaxResults] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest = {
    import DescribeLocalGatewayRouteTableVpcAssociationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
      .builder()
      .optionallyWith(
        localGatewayRouteTableVpcAssociationIds.map(value =>
          value.map { item =>
            LocalGatewayRouteTableVpcAssociationId.unwrap(
              item
            ): java.lang.String
          }.asJavaCollection
        )
      )(_.localGatewayRouteTableVpcAssociationIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => LocalGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
      .wrap(buildAwsValue())
}
object DescribeLocalGatewayRouteTableVpcAssociationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest =
      zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest(
        localGatewayRouteTableVpcAssociationIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def localGatewayRouteTableVpcAssociationIds
        : Option[List[LocalGatewayRouteTableVpcAssociationId]]
    def filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Option[LocalGatewayMaxResults]
    def nextToken: Option[String]
    def getLocalGatewayRouteTableVpcAssociationIds
        : ZIO[Any, AwsError, List[LocalGatewayRouteTableVpcAssociationId]] =
      AwsError.unwrapOptionField(
        "localGatewayRouteTableVpcAssociationIds",
        localGatewayRouteTableVpcAssociationIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, LocalGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ) extends zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly {
    override val localGatewayRouteTableVpcAssociationIds
        : Option[List[LocalGatewayRouteTableVpcAssociationId]] = scala
      .Option(impl.localGatewayRouteTableVpcAssociationIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives
            .LocalGatewayRouteTableVpcAssociationId(item)
        }.toList
      )
    override val filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      scala
        .Option(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Option[LocalGatewayMaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.ec2.model.primitives.LocalGatewayMaxResults(value))
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ): zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.295.10-sources.jar: zio/aws/ec2/model/DescribeLocalGatewayRouteTableVpcAssociationsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  LocalGatewayMaxResults,
  LocalGatewayRouteTableVpcAssociationId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeLocalGatewayRouteTableVpcAssociationsRequest(
    localGatewayRouteTableVpcAssociationIds: Optional[
      Iterable[LocalGatewayRouteTableVpcAssociationId]
    ] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[LocalGatewayMaxResults] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest = {
    import DescribeLocalGatewayRouteTableVpcAssociationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
      .builder()
      .optionallyWith(
        localGatewayRouteTableVpcAssociationIds.map(value =>
          value.map { item =>
            LocalGatewayRouteTableVpcAssociationId.unwrap(
              item
            ): java.lang.String
          }.asJavaCollection
        )
      )(_.localGatewayRouteTableVpcAssociationIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => LocalGatewayMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
      .wrap(buildAwsValue())
}
object DescribeLocalGatewayRouteTableVpcAssociationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest =
      zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest(
        localGatewayRouteTableVpcAssociationIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def localGatewayRouteTableVpcAssociationIds
        : Optional[List[LocalGatewayRouteTableVpcAssociationId]]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[LocalGatewayMaxResults]
    def nextToken: Optional[String]
    def getLocalGatewayRouteTableVpcAssociationIds
        : ZIO[Any, AwsError, List[LocalGatewayRouteTableVpcAssociationId]] =
      AwsError.unwrapOptionField(
        "localGatewayRouteTableVpcAssociationIds",
        localGatewayRouteTableVpcAssociationIds
      )
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, LocalGatewayMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ) extends zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly {
    override val localGatewayRouteTableVpcAssociationIds
        : Optional[List[LocalGatewayRouteTableVpcAssociationId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.localGatewayRouteTableVpcAssociationIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives
              .LocalGatewayRouteTableVpcAssociationId(item)
          }.toList
        )
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[LocalGatewayMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.LocalGatewayMaxResults(value)
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest
  ): zio.aws.ec2.model.DescribeLocalGatewayRouteTableVpcAssociationsRequest.ReadOnly =
    new Wrapper(impl)
}
